--  generated parser support file. -*- buffer-read-only:t  -*-
--  command line: wisitoken-bnf-generate.exe  --generate TREE_SITTER Ada_Emacs tree_sitter PROCESS ada_annex_p.wy
--

--  Copyright (C) 2013 - 2023 Free Software Foundation, Inc.

--  This program is free software; you can redistribute it and/or
--  modify it under the terms of the GNU General Public License as
--  published by the Free Software Foundation; either version 3, or (at
--  your option) any later version.
--
--  This software is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--  General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with GNU Emacs.  If not, see <https://www.gnu.org/licenses/>.

with Ada_Annex_P_Process_Tree_Sitter_Actions; use Ada_Annex_P_Process_Tree_Sitter_Actions;
package body Ada_Annex_P_Process_Tree_Sitter_Main is

end Ada_Annex_P_Process_Tree_Sitter_Main;
